==> haskell-wai-app-static-3.1.6.1-110-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.1
id: wai-app-static-3.1.6.1-1GeE3EMNEhB7xDNDXLPSZM
key: wai-app-static-3.1.6.1-1GeE3EMNEhB7xDNDXLPSZM
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: ef42d5cd5e6168cd278b35ae1b28c350
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-app-static-3.1.6.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-app-static-3.1.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-app-static-3.1.6.1
hs-libraries: HSwai-app-static-3.1.6.1-1GeE3EMNEhB7xDNDXLPSZM
depends:
    base-4.10.1.0 wai-3.2.1.1-CxsYXmrc3SU8ilHGN3PgZ bytestring-0.10.8.2
    http-types-0.9.1-LLq3nvC0GR761npQ3LSltX transformers-0.5.2.0
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ directory-1.3.0.2
    containers-0.5.10.2 time-1.8.0.2
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
    cryptonite-0.24-3CGZ8QvILTqyKruD8P6KS
    memory-0.14.10-LwCYa6TFutlHfUbiGZd8KU
    http-date-0.0.6.1-BIfI1QKDBBCGlG6ZsYiQOY
    blaze-html-0.9.0.1-AJ5BYeepLwbHkN0LWWSQW
    blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu
    mime-types-0.1.0.7-GpJ8puV91aQIqce5VmolFE
    unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV
    template-haskell-2.12.0.0 zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM
    filepath-1.4.1.2 wai-extra-3.0.20.2-DnRUnTF4FEV4J88NqlZIRj
    optparse-applicative-0.14.0.0-5Yv3vB6F9Ec49FKuO0i7CD
    warp-3.2.13-6vBFcHpy3uGP3bmgqmhJg
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             wai-3.2.1.1-CxsYXmrc3SU8ilHGN3PgZ=3d331e058fe16e8ada8f8121006882ec
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             http-types-0.9.1-LLq3nvC0GR761npQ3LSltX=8737ff00443d120d7dd51745f32137a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
             file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG=290747ebe676cf9f89313503a2e38e54
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH=9a0562647033c21b2abf88c991a65d08
             cryptonite-0.24-3CGZ8QvILTqyKruD8P6KS=95b6b8339e4775b78724cd4e849ec62f
             memory-0.14.10-LwCYa6TFutlHfUbiGZd8KU=ab92cc9732ca92f3c7dffc63e7dfa885
             http-date-0.0.6.1-BIfI1QKDBBCGlG6ZsYiQOY=54072fb9157547e4557270fb70ad9485
             blaze-html-0.9.0.1-AJ5BYeepLwbHkN0LWWSQW=149b27858c24c2fbb2a49b79255301b8
             blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu=63159b929711dfedc567b0fafce4aed8
             mime-types-0.1.0.7-GpJ8puV91aQIqce5VmolFE=ebd5f91c17eb1302f8779b9638d52758
             unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV=db9131d5548eea6d7a3eab9f0d172004
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM=fc994ec0331fc01f98e1d968398a1aa2
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             wai-extra-3.0.20.2-DnRUnTF4FEV4J88NqlZIRj=1df45c0dd3e2110badf4a6f7a81f4dfe
             optparse-applicative-0.14.0.0-5Yv3vB6F9Ec49FKuO0i7CD=2bb44692b9320595dee3f24a6404fc58
             warp-3.2.13-6vBFcHpy3uGP3bmgqmhJg=15bee447fd2ff81e9aea3ec6aecec803
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.6.1-111-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.6.1
id: wai-app-static-3.1.6.1-91uNwypUsDvIOZYDO3TIHi
key: wai-app-static-3.1.6.1-91uNwypUsDvIOZYDO3TIHi
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
abi: 647e2e270fa2844f44c18eae5f829053
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-app-static-3.1.6.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-app-static-3.1.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-app-static-3.1.6.1
hs-libraries: HSwai-app-static-3.1.6.1-91uNwypUsDvIOZYDO3TIHi
depends:
    base-4.10.1.0 wai-3.2.1.1-CxsYXmrc3SU8ilHGN3PgZ bytestring-0.10.8.2
    http-types-0.9.1-LLq3nvC0GR761npQ3LSltX transformers-0.5.2.0
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ directory-1.3.0.2
    containers-0.5.10.2 time-1.8.0.2
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9
    file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
    cryptonite-0.24-3CGZ8QvILTqyKruD8P6KS
    memory-0.14.10-LwCYa6TFutlHfUbiGZd8KU
    http-date-0.0.6.1-BIfI1QKDBBCGlG6ZsYiQOY
    blaze-html-0.9.0.1-AJ5BYeepLwbHkN0LWWSQW
    blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu
    mime-types-0.1.0.7-GpJ8puV91aQIqce5VmolFE
    unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV
    template-haskell-2.12.0.0 zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM
    filepath-1.4.1.2 wai-extra-3.0.20.2-DnRUnTF4FEV4J88NqlZIRj
    optparse-applicative-0.14.0.0-5Yv3vB6F9Ec49FKuO0i7CD
    warp-3.2.13-6CYBQgWmToL3UZ1L3X3o9E
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             wai-3.2.1.1-CxsYXmrc3SU8ilHGN3PgZ=3d331e058fe16e8ada8f8121006882ec
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             http-types-0.9.1-LLq3nvC0GR761npQ3LSltX=8737ff00443d120d7dd51745f32137a9
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=a09774905d29698e6c89ba4927e5c216
             file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG=290747ebe676cf9f89313503a2e38e54
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH=9a0562647033c21b2abf88c991a65d08
             cryptonite-0.24-3CGZ8QvILTqyKruD8P6KS=95b6b8339e4775b78724cd4e849ec62f
             memory-0.14.10-LwCYa6TFutlHfUbiGZd8KU=ab92cc9732ca92f3c7dffc63e7dfa885
             http-date-0.0.6.1-BIfI1QKDBBCGlG6ZsYiQOY=54072fb9157547e4557270fb70ad9485
             blaze-html-0.9.0.1-AJ5BYeepLwbHkN0LWWSQW=149b27858c24c2fbb2a49b79255301b8
             blaze-markup-0.8.0.0-KhGWK8j3xIT2gHtdkKPmyu=63159b929711dfedc567b0fafce4aed8
             mime-types-0.1.0.7-GpJ8puV91aQIqce5VmolFE=ebd5f91c17eb1302f8779b9638d52758
             unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV=db9131d5548eea6d7a3eab9f0d172004
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM=fc994ec0331fc01f98e1d968398a1aa2
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             wai-extra-3.0.20.2-DnRUnTF4FEV4J88NqlZIRj=1df45c0dd3e2110badf4a6f7a81f4dfe
             optparse-applicative-0.14.0.0-5Yv3vB6F9Ec49FKuO0i7CD=2bb44692b9320595dee3f24a6404fc58
             warp-3.2.13-6CYBQgWmToL3UZ1L3X3o9E=dbf06e61aab41ca003d2315eb7471a8b
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
